@@ -1,7 +1,7 @@
 import asyncio
 import contextlib
 import threading
-from typing import Dict, Any
+from typing import Any, Dict
 
 from contextvars import ContextVar
 
@@ -26,6 +26,10 @@ class ContextData(object):
     def __contains__(self, item):
         return item in self.__dict__
 
+    @property
+    def raw_id(self):
+        return self._id
+
     @property
     def session_id(self):
         if self._id:
