@@ -1,8 +1,10 @@
 try:
     import aioredis
 
+    from .cache import SimpleRedisCache, HashRedisCache
     from .engine import EngineConfig, RedisEngineBackend, RedisEngine
-    from .model import RedisModel, RedisMethodCache
+    from .model import RedisCacheType, RedisModel
+    from .repositories import RedisModelRepository, RedisProxyRepository
     from .settings import RedisSettings
 
     USE_REDIS = True
