@@ -1,7 +1,9 @@
 try:
-    import aioredis
+    import aio_pika
 
     from .engine import EngineConfig, RmqEngineBackend, RmqEngine
+    from .server import RmqServer
+    from .client import RmqClient
     from .settings import RmqSettings
 
     USE_RMQ = True
